package jp.flashcast.translator.android.adapter;

import java.util.ArrayList;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.view.View.OnClickListener;
import android.widget.BaseAdapter;
import android.widget.ImageView;
import android.widget.TextView;
import jp.flashcast.translator.android.R;
import jp.flashcast.translator.android.manager.HistoryManager;
import jp.flashcast.translator.android.model.TranslateModel;
import jp.flashcast.translator.android.view.TranslateListView;

public class TranslateAdapter extends BaseAdapter {
	private LayoutInflater inflater;
	private ArrayList<TranslateModel> list;
	private HistoryManager manager;
	
	public TranslateAdapter(Context context, ArrayList<TranslateModel> list, HistoryManager manager) {
		this.list = list;
		this.manager = manager;
		this.inflater = (LayoutInflater)context.getSystemService(Context.LAYOUT_INFLATER_SERVICE);
	}
	
	public int getCount() {
		return list.size();
	}

	public Object getItem(int position) {
		return list.get(position);
	}

	public long getItemId(int position) {
		return list.get(position).getId();
	}

	public View getView(int position, View convertView, ViewGroup parent) {
		convertView = inflater.inflate(R.layout.list_item, null);
		
		TextView original = (TextView)convertView.findViewById(R.id.original);
		TextView translated = (TextView)convertView.findViewById(R.id.translated);
		TextView dt = (TextView)convertView.findViewById(R.id.dt);
		ImageView image = (ImageView)convertView.findViewById(R.id.delete);
		
		original.setText(list.get(position).getOriginal());
		translated.setText(list.get(position).getTranslated());
		dt.setText(list.get(position).getDt());
		image.setImageResource(android.R.drawable.ic_menu_delete);
		image.setId(list.get(position).getId());
		
		image.setOnClickListener(new OnClickListener() {

			public void onClick(View v) {
				manager.delete(v.getId());
				int max = manager.getHistoriesCount();
				int len = manager.setTranslateAdapter(TranslateAdapter.this, true);
				int pos = HistoryManager.HISTORY_LIST_VIEW_COUNT * (manager.getPage() - 1);
				TranslateListView view = ((TranslateListView)v.getParent().getParent());
				view.setAdapter(TranslateAdapter.this);
				view.setFooterVisible(!(len == max));
				view.setSelection((max > pos) ? pos : max);
			}
			
		});
		
		return convertView;
	}
	
	public void add(TranslateModel model) {
		list.add(model);
	}
	
	public void clear() {
		list.clear();
	}
}
